@@ -6,20 +6,18 @@
 
 #include "ExternalAppModule.h"
 
-#include <KCModuleInfo>
 #include <KIO/ApplicationLauncherJob>
 #include <KIO/JobUiDelegateFactory>
+#include <QDebug>
 
-ExternalAppModule::ExternalAppModule(QWidget *parent, const KService::Ptr &module)
-    : module(module)
+ExternalAppModule::ExternalAppModule(const KService::Ptr &service)
+    : moduleService(service)
 {
-    Q_UNUSED(parent)
-
     firstShow = true;
     externalModule.setupUi(this);
-    QString moduleName = module->name();
+    QString moduleName = moduleService->name();
     if (moduleName.isEmpty()) {
-        moduleName = module->property(QStringLiteral("X-KDE-PluginInfo-Name"), QMetaType::QString).toString();
+        moduleName = moduleService->property<QString>(QStringLiteral("X-KDE-PluginInfo-Name"));
         if (!moduleName.isEmpty()) {
             qWarning() << "Reading deprecated X-KDE-PluginInfo-Name property from ExternalAppModule, use Name property instead";
         }
@@ -44,7 +42,9 @@ void ExternalAppModule::showEvent(QShowEvent *event)
 
 void ExternalAppModule::runExternal()
 {
-    KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob(module);
+    auto job = new KIO::ApplicationLauncherJob(moduleService);
     job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
     job->start();
 }
+
+#include "moc_ExternalAppModule.cpp"
